@@ -1,6 +1,6 @@
 /* apt-dater - terminal-based remote package update manager
  *
- * $Id: apt-dater.c 540 2010-12-03 09:53:51Z ellguth $
+ * $Id: apt-dater.c 582 2011-09-27 13:45:43Z ellguth $
  *
  * Authors:
  *   Andre Ellguth <ellguth@ibh.de>
@@ -28,6 +28,9 @@
 #include <glib.h>
 #include <glib/gstdio.h>
 #include <errno.h>
+#ifdef HAVE_LOCALE_H
+#include <locale.h>
+#endif
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
